CtzonApiSettings class

Constructors

CtzonApiSettings()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

commercialKey String
getter/setter pair
homePage StatefulWidget?
getter/setter pair
isDev bool
getter/setter pair
loaderAsset String?
getter/setter pair
privacyUrl String?
getter/setter pair
socialLogin bool
getter/setter pair
thermsUrl String?
getter/setter pair

Static Methods

getApiUrl() String
set(String commercialKey, bool dev, StatefulWidget homePage, {String privacyUrl = "", String thermsUrl = "", bool socialLogin = false, String? loaderAsset}) → void

Constants

apiUrl → const String
apiUrlDev → const String