AccountPrivileges class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AccountPrivileges(int is_admin, Map<
String, bool> ? details) -
AccountPrivileges.fromJson(Map<
String, dynamic> json) -
factory
Properties
- active ↔ bool
-
getter/setter pair
-
details
↔ Map<
String, bool> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- is_admin ↔ int
-
getter/setter pair
- order ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited