AccountAddress class sealed

Available extensions
Annotations
  • @freezed

Constructors

AccountAddress({@JsonKey.new(name: 'id') required int id, @JsonKey.new(name: 'account_id') required int accountId, @JsonKey.new(name: 'address') required String address, @JsonKey.new(name: 'city') required String city, @JsonKey.new(name: 'zip_code') required String zipCode, @JsonKey.new(name: 'province') required String province, @JsonKey.new(name: 'country') required String country, @JsonKey.new(name: 'tax_code') String? taxCode, @JsonKey.new(name: 'vat_number') String? vatNumber, @JsonKey.new(name: 'business_name') String? businessName, @JsonKey.new(name: 'deleted_at') DateTime? deletedAt, @JsonKey.new(name: 'created_at') DateTime? createdAt, @JsonKey.new(name: 'updated_at') DateTime? updatedAt})
const
factory
AccountAddress.fromJson(Map<String, dynamic> json)
factory

Properties

accountId int
no setterinherited
address String
no setterinherited
businessName String?
no setterinherited
city String
no setterinherited
copyWith → $AccountAddressCopyWith<AccountAddress>
Create a copy of AccountAddress with the given fields replaced by the non-null parameter values.
no setterinherited
country String
no setterinherited
createdAt DateTime?
no setterinherited
deletedAt DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
province String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxCode String?
no setterinherited
updatedAt DateTime?
no setterinherited
vatNumber String?
no setterinherited
zipCode String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AccountAddress value)) → TResult

Available on AccountAddress, provided by the AccountAddressPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AccountAddress value)?) → TResult?

Available on AccountAddress, provided by the AccountAddressPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AccountAddress value)?, {required TResult orElse()}) → TResult

Available on AccountAddress, provided by the AccountAddressPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int accountId, String address, String city, String zipCode, String province, String country, String? taxCode, String? vatNumber, String? businessName, DateTime? deletedAt, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult

Available on AccountAddress, provided by the AccountAddressPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AccountAddress to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int accountId, String address, String city, String zipCode, String province, String country, String? taxCode, String? vatNumber, String? businessName, DateTime? deletedAt, DateTime? createdAt, DateTime? updatedAt)) → TResult

Available on AccountAddress, provided by the AccountAddressPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int accountId, String address, String city, String zipCode, String province, String country, String? taxCode, String? vatNumber, String? businessName, DateTime? deletedAt, DateTime? createdAt, DateTime? updatedAt)?) → TResult?

Available on AccountAddress, provided by the AccountAddressPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited