Commercial class

Annotations

Constructors

Commercial(int id, String local_id, Jiffy creation, int points, int promo_24_week, int is_on_ctzon, String name)
Commercial.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
getter/setter pair
cap String?
getter/setter pair
creation ↔ Jiffy
getter/setter pair
description String?
getter/setter pair
email String?
getter/setter pair
first_activation ↔ Jiffy?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
is_on_ctzon int
getter/setter pair
iva String?
getter/setter pair
last_activation ↔ Jiffy?
getter/setter pair
latitude num?
getter/setter pair
local_id String
getter/setter pair
getter/setter pair
longitude num?
getter/setter pair
name String
getter/setter pair
phone String?
getter/setter pair
points int
getter/setter pair
promo_24_week int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
society String?
getter/setter pair
website String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited