CommercialPointPack class sealed

Available extensions
Annotations
  • @freezed

Constructors

CommercialPointPack({required int id, @JsonKey.new(name: 'commercial_local_id') required String commercialLocalId, required String name, @JsonKey.new(name: 'description_discount') String? descriptionDiscount, required num price, required int points, String? note, @JsonKey.new(name: 'created_at') @TimestampConverter() Jiffy? createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() Jiffy? updatedAt})
const
factory
CommercialPointPack.fromJson(Map<String, dynamic> json)
factory

Properties

commercialLocalId String
no setterinherited
copyWith → $CommercialPointPackCopyWith<CommercialPointPack>
Create a copy of CommercialPointPack with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → Jiffy?
no setterinherited
descriptionDiscount String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
name String
no setterinherited
note String?
no setterinherited
points int
no setterinherited
price num
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → Jiffy?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CommercialPointPack value)) → TResult

Available on CommercialPointPack, provided by the CommercialPointPackPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CommercialPointPack value)?) → TResult?

Available on CommercialPointPack, provided by the CommercialPointPackPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CommercialPointPack value)?, {required TResult orElse()}) → TResult

Available on CommercialPointPack, provided by the CommercialPointPackPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, String commercialLocalId, String name, String? descriptionDiscount, num price, int points, String? note, Jiffy? createdAt, Jiffy? updatedAt)?, {required TResult orElse()}) → TResult

Available on CommercialPointPack, provided by the CommercialPointPackPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommercialPointPack to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, String commercialLocalId, String name, String? descriptionDiscount, num price, int points, String? note, Jiffy? createdAt, Jiffy? updatedAt)) → TResult

Available on CommercialPointPack, provided by the CommercialPointPackPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, String commercialLocalId, String name, String? descriptionDiscount, num price, int points, String? note, Jiffy? createdAt, Jiffy? updatedAt)?) → TResult?

Available on CommercialPointPack, provided by the CommercialPointPackPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited