IsibookActivity class sealed

Available extensions
Annotations
  • @freezed

Constructors

IsibookActivity({required int id, @JsonKey.new(name: 'commercial_id') required int commercialId, required String name, required String description, required List images, required List tags, @JsonKey.new(name: 'isibook_space_id') required int isibookSpaceId, @JsonKey.new(name: 'number_of_seats') required int numberOfSeats, @JsonKey.new(name: 'number_of_reserved') required int numberOfReserved, @JsonKey.new(name: 'hour_before_late') required int hourBeforeLate, required num price, @JsonKey.new(name: 'deleted_at') @TimestampConverter() Jiffy? deletedAt, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt, required List metadata, @JsonKey.new(name: 'order_column') required int orderColumn, @JsonKey.new(name: 'can_pay_with_points') required bool canPayWithPoints, @JsonKey.new(name: 'is_discount_active') required bool isDiscountActive, @JsonKey.new(name: 'cancellation_policy') required String cancellationPolicy, @JsonKey.new(name: 'date_start') @TimestampConverter() required Jiffy dateStart, @JsonKey.new(name: 'date_end') @TimestampConverter() required Jiffy dateEnd, @JsonKey.new(name: 'images_url') required List imagesUrl})
const
factory
IsibookActivity.fromJson(Map<String, dynamic> json)
factory

Properties

cancellationPolicy String
no setterinherited
canPayWithPoints bool
no setterinherited
commercialId int
no setterinherited
copyWith → $IsibookActivityCopyWith<IsibookActivity>
Create a copy of IsibookActivity with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → Jiffy
no setterinherited
dateEnd → Jiffy
no setterinherited
dateStart → Jiffy
no setterinherited
deletedAt → Jiffy?
no setterinherited
description String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hourBeforeLate int
no setterinherited
id int
no setterinherited
images List
no setterinherited
imagesUrl List
no setterinherited
isDiscountActive bool
no setterinherited
isibookSpaceId int
no setterinherited
metadata List
no setterinherited
name String
no setterinherited
numberOfReserved int
no setterinherited
numberOfSeats int
no setterinherited
orderColumn int
no setterinherited
price num
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List
no setterinherited
updatedAt → Jiffy
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IsibookActivity value)) → TResult

Available on IsibookActivity, provided by the IsibookActivityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookActivity value)?) → TResult?

Available on IsibookActivity, provided by the IsibookActivityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookActivity value)?, {required TResult orElse()}) → TResult

Available on IsibookActivity, provided by the IsibookActivityPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String description, List images, List tags, int isibookSpaceId, int numberOfSeats, int numberOfReserved, int hourBeforeLate, num price, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List metadata, int orderColumn, bool canPayWithPoints, bool isDiscountActive, String cancellationPolicy, Jiffy dateStart, Jiffy dateEnd, List imagesUrl)?, {required TResult orElse()}) → TResult

Available on IsibookActivity, provided by the IsibookActivityPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsibookActivity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String description, List images, List tags, int isibookSpaceId, int numberOfSeats, int numberOfReserved, int hourBeforeLate, num price, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List metadata, int orderColumn, bool canPayWithPoints, bool isDiscountActive, String cancellationPolicy, Jiffy dateStart, Jiffy dateEnd, List imagesUrl)) → TResult

Available on IsibookActivity, provided by the IsibookActivityPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int commercialId, String name, String description, List images, List tags, int isibookSpaceId, int numberOfSeats, int numberOfReserved, int hourBeforeLate, num price, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List metadata, int orderColumn, bool canPayWithPoints, bool isDiscountActive, String cancellationPolicy, Jiffy dateStart, Jiffy dateEnd, List imagesUrl)?) → TResult?

Available on IsibookActivity, provided by the IsibookActivityPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited