IsibookCalendarSlot class

Slot atomico di calendario calcolato per uno spazio in un determinato giorno.

Constructors

IsibookCalendarSlot({required Jiffy start, required Jiffy end, required bool available, required int accountId})
const

Properties

accountId int
final
available bool
final
end → Jiffy
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start → Jiffy
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited