IsibookIntervalPricePatterns extension

Adds pattern-matching-related methods to IsibookIntervalPrice.

on

Methods

map<TResult extends Object?>(TResult $default(_IsibookIntervalPrice value)) → TResult

Available on IsibookIntervalPrice, provided by the IsibookIntervalPricePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookIntervalPrice value)?) → TResult?

Available on IsibookIntervalPrice, provided by the IsibookIntervalPricePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookIntervalPrice value)?, {required TResult orElse()}) → TResult

Available on IsibookIntervalPrice, provided by the IsibookIntervalPricePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int slot, num price)?, {required TResult orElse()}) → TResult

Available on IsibookIntervalPrice, provided by the IsibookIntervalPricePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int slot, num price)) → TResult

Available on IsibookIntervalPrice, provided by the IsibookIntervalPricePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int slot, num price)?) → TResult?

Available on IsibookIntervalPrice, provided by the IsibookIntervalPricePatterns extension

A variant of when that fallback to returning null