IsibookMyReservationResponse class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
IsibookMyReservationResponse({required bool status, String? message, String? error, @JsonKey.new(name: 'stripe_data') dynamic stripeData, @JsonKey.new(name: 'reservation_id') int? reservationId, List<
IsibookReservationExtra> ? extras, IsibookMyReservation? reservation}) -
constfactory
-
IsibookMyReservationResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $IsibookMyReservationResponseCopyWith<
IsibookMyReservationResponse> -
Create a copy of IsibookMyReservationResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- error → String?
-
no setterinherited
-
extras
→ List<
IsibookReservationExtra> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
no setterinherited
- reservation → IsibookMyReservation?
-
no setterinherited
- reservationId → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → bool
-
no setterinherited
- stripeData → dynamic
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookMyReservationResponse value)) → TResult -
Available on IsibookMyReservationResponse, provided by the IsibookMyReservationResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookMyReservationResponse value)?) → TResult? -
Available on IsibookMyReservationResponse, provided by the IsibookMyReservationResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookMyReservationResponse value)?, {required TResult orElse()}) → TResult -
Available on IsibookMyReservationResponse, provided by the IsibookMyReservationResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool status, String? message, String? error, dynamic stripeData, int? reservationId, List< IsibookReservationExtra> ? extras, IsibookMyReservation? reservation)?, {required TResult orElse()}) → TResult -
Available on IsibookMyReservationResponse, provided by the IsibookMyReservationResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookMyReservationResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool status, String? message, String? error, dynamic stripeData, int? reservationId, List< IsibookReservationExtra> ? extras, IsibookMyReservation? reservation)) → TResult -
Available on IsibookMyReservationResponse, provided by the IsibookMyReservationResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool status, String? message, String? error, dynamic stripeData, int? reservationId, List< IsibookReservationExtra> ? extras, IsibookMyReservation? reservation)?) → TResult? -
Available on IsibookMyReservationResponse, provided by the IsibookMyReservationResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited