IsibookPointsLog class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
IsibookPointsLog({required int id, @JsonKey.new(name: 'commercial_id') required int commercialId, @JsonKey.new(name: 'account_id') required int accountId, required int points, Map<
String, dynamic> ? payment, required bool pending, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt, required String description}) -
constfactory
-
IsibookPointsLog.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountId → int
-
no setterinherited
- commercialId → int
-
no setterinherited
-
copyWith
→ $IsibookPointsLogCopyWith<
IsibookPointsLog> -
Create a copy of IsibookPointsLog
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → Jiffy
-
no setterinherited
- description → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
-
payment
→ Map<
String, dynamic> ? -
no setterinherited
- pending → bool
-
no setterinherited
- points → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → Jiffy
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookPointsLog value)) → TResult -
Available on IsibookPointsLog, provided by the IsibookPointsLogPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookPointsLog value)?) → TResult? -
Available on IsibookPointsLog, provided by the IsibookPointsLogPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookPointsLog value)?, {required TResult orElse()}) → TResult -
Available on IsibookPointsLog, provided by the IsibookPointsLogPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int id, int commercialId, int accountId, int points, Map< String, dynamic> ? payment, bool pending, Jiffy createdAt, Jiffy updatedAt, String description)?, {required TResult orElse()}) → TResult -
Available on IsibookPointsLog, provided by the IsibookPointsLogPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookPointsLog to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int id, int commercialId, int accountId, int points, Map< String, dynamic> ? payment, bool pending, Jiffy createdAt, Jiffy updatedAt, String description)) → TResult -
Available on IsibookPointsLog, provided by the IsibookPointsLogPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int id, int commercialId, int accountId, int points, Map< String, dynamic> ? payment, bool pending, Jiffy createdAt, Jiffy updatedAt, String description)?) → TResult? -
Available on IsibookPointsLog, provided by the IsibookPointsLogPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited