IsibookPointsResponse class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- IsibookPointsResponse({required bool status, String? message, required IsibookPoints points})
-
constfactory
-
IsibookPointsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $IsibookPointsResponseCopyWith<
IsibookPointsResponse> -
Create a copy of IsibookPointsResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
no setterinherited
- points → IsibookPoints
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookPointsResponse value)) → TResult -
Available on IsibookPointsResponse, provided by the IsibookPointsResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookPointsResponse value)?) → TResult? -
Available on IsibookPointsResponse, provided by the IsibookPointsResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookPointsResponse value)?, {required TResult orElse()}) → TResult -
Available on IsibookPointsResponse, provided by the IsibookPointsResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool status, String? message, IsibookPoints points)?, {required TResult orElse()}) → TResult -
Available on IsibookPointsResponse, provided by the IsibookPointsResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookPointsResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool status, String? message, IsibookPoints points)) → TResult -
Available on IsibookPointsResponse, provided by the IsibookPointsResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool status, String? message, IsibookPoints points)?) → TResult? -
Available on IsibookPointsResponse, provided by the IsibookPointsResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited