toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'IsibookReservation(id: $id, commercialId: $commercialId, isibookSpacesId: $isibookSpacesId, extras: $extras, paymentType: $paymentType, electronicConfirmed: $electronicConfirmed, amountPayed: $amountPayed, customers: $customers, reservationId: $reservationId, accountId: $accountId, accountTemp: $accountTemp, createdAt: $createdAt, updatedAt: $updatedAt, datetimeFirstSlot: $datetimeFirstSlot, datetimeLastSlot: $datetimeLastSlot, cancelAt: $cancelAt, cancelBy: $cancelBy, isibookSpaceActivityId: $isibookSpaceActivityId, isibookSpaceActivityConnectedId: $isibookSpaceActivityConnectedId, recoverCodeFattura: $recoverCodeFattura, errorFattura: $errorFattura, needFattura: $needFattura, backoffice: $backoffice, note: $note)';
}