IsibookReservationExtra class sealed

Available extensions
Annotations
  • @freezed

Constructors

IsibookReservationExtra({required int id, @JsonKey.new(name: 'commercial_id') required int commercialId, required String name, required String description, required List<String> images, @JsonKey.new(name: 'min_number_slot_reserved') required int minNumberSlotReserved, @JsonKey.new(name: 'max_number_slot_reserved') required int maxNumberSlotReserved, required List<IsibookExtraPrice> price, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt, @JsonKey.new(name: 'deleted_at') @TimestampConverter() Jiffy? deletedAt, @JsonKey.new(name: 'images_url') required List<String> imagesUrl})
const
factory
IsibookReservationExtra.fromJson(Map<String, dynamic> json)
factory

Properties

commercialId int
no setterinherited
copyWith → $IsibookReservationExtraCopyWith<IsibookReservationExtra>
Create a copy of IsibookReservationExtra with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → Jiffy
no setterinherited
deletedAt → Jiffy?
no setterinherited
description String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
images List<String>
no setterinherited
imagesUrl List<String>
no setterinherited
maxNumberSlotReserved int
no setterinherited
minNumberSlotReserved int
no setterinherited
name String
no setterinherited
price List<IsibookExtraPrice>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → Jiffy
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IsibookReservationExtra value)) → TResult

Available on IsibookReservationExtra, provided by the IsibookReservationExtraPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookReservationExtra value)?) → TResult?

Available on IsibookReservationExtra, provided by the IsibookReservationExtraPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookReservationExtra value)?, {required TResult orElse()}) → TResult

Available on IsibookReservationExtra, provided by the IsibookReservationExtraPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String description, List<String> images, int minNumberSlotReserved, int maxNumberSlotReserved, List<IsibookExtraPrice> price, Jiffy createdAt, Jiffy updatedAt, Jiffy? deletedAt, List<String> imagesUrl)?, {required TResult orElse()}) → TResult

Available on IsibookReservationExtra, provided by the IsibookReservationExtraPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsibookReservationExtra to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String description, List<String> images, int minNumberSlotReserved, int maxNumberSlotReserved, List<IsibookExtraPrice> price, Jiffy createdAt, Jiffy updatedAt, Jiffy? deletedAt, List<String> imagesUrl)) → TResult

Available on IsibookReservationExtra, provided by the IsibookReservationExtraPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int commercialId, String name, String description, List<String> images, int minNumberSlotReserved, int maxNumberSlotReserved, List<IsibookExtraPrice> price, Jiffy createdAt, Jiffy updatedAt, Jiffy? deletedAt, List<String> imagesUrl)?) → TResult?

Available on IsibookReservationExtra, provided by the IsibookReservationExtraPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited