IsibookReservationPatterns extension

Adds pattern-matching-related methods to IsibookReservation.

on

Methods

map<TResult extends Object?>(TResult $default(_IsibookReservation value)) → TResult

Available on IsibookReservation, provided by the IsibookReservationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookReservation value)?) → TResult?

Available on IsibookReservation, provided by the IsibookReservationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookReservation value)?, {required TResult orElse()}) → TResult

Available on IsibookReservation, provided by the IsibookReservationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int commercialId, int isibookSpacesId, List<int> extras, IsibookPaymentType paymentType, dynamic electronicConfirmed, num amountPayed, int customers, int reservationId, int accountId, dynamic accountTemp, Jiffy createdAt, Jiffy updatedAt, Jiffy datetimeFirstSlot, Jiffy datetimeLastSlot, Jiffy? cancelAt, String? cancelBy, int? isibookSpaceActivityId, int? isibookSpaceActivityConnectedId, String? recoverCodeFattura, String? errorFattura, bool needFattura, bool backoffice, String? note)?, {required TResult orElse()}) → TResult

Available on IsibookReservation, provided by the IsibookReservationPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int id, int commercialId, int isibookSpacesId, List<int> extras, IsibookPaymentType paymentType, dynamic electronicConfirmed, num amountPayed, int customers, int reservationId, int accountId, dynamic accountTemp, Jiffy createdAt, Jiffy updatedAt, Jiffy datetimeFirstSlot, Jiffy datetimeLastSlot, Jiffy? cancelAt, String? cancelBy, int? isibookSpaceActivityId, int? isibookSpaceActivityConnectedId, String? recoverCodeFattura, String? errorFattura, bool needFattura, bool backoffice, String? note)) → TResult

Available on IsibookReservation, provided by the IsibookReservationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int commercialId, int isibookSpacesId, List<int> extras, IsibookPaymentType paymentType, dynamic electronicConfirmed, num amountPayed, int customers, int reservationId, int accountId, dynamic accountTemp, Jiffy createdAt, Jiffy updatedAt, Jiffy datetimeFirstSlot, Jiffy datetimeLastSlot, Jiffy? cancelAt, String? cancelBy, int? isibookSpaceActivityId, int? isibookSpaceActivityConnectedId, String? recoverCodeFattura, String? errorFattura, bool needFattura, bool backoffice, String? note)?) → TResult?

Available on IsibookReservation, provided by the IsibookReservationPatterns extension

A variant of when that fallback to returning null