IsibookReservationsPage class sealed

Available extensions
Annotations
  • @freezed

Constructors

IsibookReservationsPage({@JsonKey.new(name: 'current_page') required int currentPage, required List<IsibookMyReservation> data, @JsonKey.new(name: 'first_page_url') String? firstPageUrl, int? from, @JsonKey.new(name: 'last_page') int? lastPage, @JsonKey.new(name: 'last_page_url') String? lastPageUrl, required List<IsibookReservationLink> links, @JsonKey.new(name: 'next_page_url') String? nextPageUrl, required String path, @JsonKey.new(name: 'per_page') required int perPage, @JsonKey.new(name: 'prev_page_url') String? prevPageUrl, int? to, int? total})
const
factory
IsibookReservationsPage.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $IsibookReservationsPageCopyWith<IsibookReservationsPage>
Create a copy of IsibookReservationsPage with the given fields replaced by the non-null parameter values.
no setterinherited
currentPage int
no setterinherited
data List<IsibookMyReservation>
no setterinherited
firstPageUrl String?
no setterinherited
from int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
lastPage int?
no setterinherited
lastPageUrl String?
no setterinherited
no setterinherited
nextPageUrl String?
no setterinherited
path String
no setterinherited
perPage int
no setterinherited
prevPageUrl String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to int?
no setterinherited
total int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IsibookReservationsPage value)) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookReservationsPage value)?) → TResult?

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookReservationsPage value)?, {required TResult orElse()}) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int currentPage, List<IsibookMyReservation> data, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<IsibookReservationLink> links, String? nextPageUrl, String path, int perPage, String? prevPageUrl, int? to, int? total)?, {required TResult orElse()}) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsibookReservationsPage to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int currentPage, List<IsibookMyReservation> data, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<IsibookReservationLink> links, String? nextPageUrl, String path, int perPage, String? prevPageUrl, int? to, int? total)) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int currentPage, List<IsibookMyReservation> data, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<IsibookReservationLink> links, String? nextPageUrl, String path, int perPage, String? prevPageUrl, int? to, int? total)?) → TResult?

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited