IsibookReservationsPagePatterns extension

Adds pattern-matching-related methods to IsibookReservationsPage.

on

Methods

map<TResult extends Object?>(TResult $default(_IsibookReservationsPage value)) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookReservationsPage value)?) → TResult?

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookReservationsPage value)?, {required TResult orElse()}) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int currentPage, List<IsibookMyReservation> data, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<IsibookReservationLink> links, String? nextPageUrl, String path, int perPage, String? prevPageUrl, int? to, int? total)?, {required TResult orElse()}) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int currentPage, List<IsibookMyReservation> data, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<IsibookReservationLink> links, String? nextPageUrl, String path, int perPage, String? prevPageUrl, int? to, int? total)) → TResult

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int currentPage, List<IsibookMyReservation> data, String? firstPageUrl, int? from, int? lastPage, String? lastPageUrl, List<IsibookReservationLink> links, String? nextPageUrl, String path, int perPage, String? prevPageUrl, int? to, int? total)?) → TResult?

Available on IsibookReservationsPage, provided by the IsibookReservationsPagePatterns extension

A variant of when that fallback to returning null