IsibookReservationsResponse class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
IsibookReservationsResponse({required bool status, String? message, @JsonKey.new(name: 'slots_count') required int slotsCount, required List<
IsibookReservation> reservations, required List<IsibookActivity> activities}) -
constfactory
-
IsibookReservationsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
activities
→ List<
IsibookActivity> -
no setterinherited
-
copyWith
→ $IsibookReservationsResponseCopyWith<
IsibookReservationsResponse> -
Create a copy of IsibookReservationsResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
no setterinherited
-
reservations
→ List<
IsibookReservation> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotsCount → int
-
no setterinherited
- status → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookReservationsResponse value)) → TResult -
Available on IsibookReservationsResponse, provided by the IsibookReservationsResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookReservationsResponse value)?) → TResult? -
Available on IsibookReservationsResponse, provided by the IsibookReservationsResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookReservationsResponse value)?, {required TResult orElse()}) → TResult -
Available on IsibookReservationsResponse, provided by the IsibookReservationsResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(bool status, String? message, int slotsCount, List< IsibookReservation> reservations, List<IsibookActivity> activities)?, {required TResult orElse()}) → TResult -
Available on IsibookReservationsResponse, provided by the IsibookReservationsResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookReservationsResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(bool status, String? message, int slotsCount, List< IsibookReservation> reservations, List<IsibookActivity> activities)) → TResult -
Available on IsibookReservationsResponse, provided by the IsibookReservationsResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(bool status, String? message, int slotsCount, List< IsibookReservation> reservations, List<IsibookActivity> activities)?) → TResult? -
Available on IsibookReservationsResponse, provided by the IsibookReservationsResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited