IsibookReserveCheckResponse class sealed

Available extensions
Annotations
  • @freezed

Constructors

IsibookReserveCheckResponse({required bool status, String? message, String? error, required IsibookReserveTotal total})
const
factory
IsibookReserveCheckResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $IsibookReserveCheckResponseCopyWith<IsibookReserveCheckResponse>
Create a copy of IsibookReserveCheckResponse with the given fields replaced by the non-null parameter values.
no setterinherited
error String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool
no setterinherited
total IsibookReserveTotal
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IsibookReserveCheckResponse value)) → TResult

Available on IsibookReserveCheckResponse, provided by the IsibookReserveCheckResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookReserveCheckResponse value)?) → TResult?

Available on IsibookReserveCheckResponse, provided by the IsibookReserveCheckResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookReserveCheckResponse value)?, {required TResult orElse()}) → TResult

Available on IsibookReserveCheckResponse, provided by the IsibookReserveCheckResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool status, String? message, String? error, IsibookReserveTotal total)?, {required TResult orElse()}) → TResult

Available on IsibookReserveCheckResponse, provided by the IsibookReserveCheckResponsePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsibookReserveCheckResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool status, String? message, String? error, IsibookReserveTotal total)) → TResult

Available on IsibookReserveCheckResponse, provided by the IsibookReserveCheckResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool status, String? message, String? error, IsibookReserveTotal total)?) → TResult?

Available on IsibookReserveCheckResponse, provided by the IsibookReserveCheckResponsePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited