IsibookReserveTotal class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- IsibookReserveTotal({required num total, @JsonKey.new(name: 'discount_total') required num discountTotal, required num discount})
-
constfactory
-
IsibookReserveTotal.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $IsibookReserveTotalCopyWith<
IsibookReserveTotal> -
Create a copy of IsibookReserveTotal
with the given fields replaced by the non-null parameter values.
no setterinherited
- discount → num
-
no setterinherited
- discountTotal → num
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → num
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookReserveTotal value)) → TResult -
Available on IsibookReserveTotal, provided by the IsibookReserveTotalPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookReserveTotal value)?) → TResult? -
Available on IsibookReserveTotal, provided by the IsibookReserveTotalPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookReserveTotal value)?, {required TResult orElse()}) → TResult -
Available on IsibookReserveTotal, provided by the IsibookReserveTotalPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(num total, num discountTotal, num discount)?, {required TResult orElse()}) → TResult -
Available on IsibookReserveTotal, provided by the IsibookReserveTotalPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookReserveTotal to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(num total, num discountTotal, num discount)) → TResult -
Available on IsibookReserveTotal, provided by the IsibookReserveTotalPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(num total, num discountTotal, num discount)?) → TResult? -
Available on IsibookReserveTotal, provided by the IsibookReserveTotalPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited