IsibookSpace class sealed

Available extensions
Annotations
  • @freezed

Constructors

IsibookSpace({required int id, @JsonKey.new(name: 'commercial_id') required int commercialId, required String name, String? description, @JsonKey.new(name: 'max_people') required int maxPeople, @JsonKey.new(name: 'slot_interval') required int slotInterval, @JsonKey.new(name: 'interval_price') required List<IsibookIntervalPrice> intervalPrice, required List images, @JsonKey.new(name: 'meta_value') required List metaValue, @JsonKey.new(name: 'deleted_at') @TimestampConverter() Jiffy? deletedAt, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt, required List tags, @JsonKey.new(name: 'min_number_slot_reserved') required int minNumberSlotReserved, @JsonKey.new(name: 'max_number_slot_reserved') required int maxNumberSlotReserved, @JsonKey.new(name: 'spaces') required List<int> spaces, @JsonKey.new(name: 'order_column') required int orderColumn, required List<int> extras, @JsonKey.new(name: 'can_pay_with_points') required bool canPayWithPoints, @JsonKey.new(name: 'is_discount_active') required bool isDiscountActive, String? color, @JsonKey.new(name: 'images_url') required List imagesUrl, @JsonKey.new(name: 'isibook_space_time_slots') required List<IsibookSpaceTimeSlot> timeSlots})
const
factory
IsibookSpace.fromJson(Map<String, dynamic> json)
factory

Properties

canPayWithPoints bool
no setterinherited
color String?
no setterinherited
commercialId int
no setterinherited
copyWith → $IsibookSpaceCopyWith<IsibookSpace>
Create a copy of IsibookSpace with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → Jiffy
no setterinherited
deletedAt → Jiffy?
no setterinherited
description String?
no setterinherited
extras List<int>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
images List
no setterinherited
imagesUrl List
no setterinherited
intervalPrice List<IsibookIntervalPrice>
no setterinherited
isDiscountActive bool
no setterinherited
maxNumberSlotReserved int
no setterinherited
maxPeople int
no setterinherited
metaValue List
no setterinherited
minNumberSlotReserved int
no setterinherited
name String
no setterinherited
orderColumn int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotInterval int
no setterinherited
spaces List<int>
no setterinherited
tags List
no setterinherited
timeSlots List<IsibookSpaceTimeSlot>
no setterinherited
updatedAt → Jiffy
no setterinherited

Methods

buildCalendarSlotsForDay({required Jiffy day, required List<IsibookReservation> reservations}) List<IsibookCalendarSlot>
Costruisce gli slot atomici di calendario per un determinato giorno.
canBook({required List<IsibookCalendarSlot> slots, required int startIndex, required int length}) bool
Verifica se è possibile prenotare una sequenza di slot a partire da startIndex lunga length slot, rispettando min/max_number_slot_reserved e disponibilità.
map<TResult extends Object?>(TResult $default(_IsibookSpace value)) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookSpace value)?) → TResult?

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookSpace value)?, {required TResult orElse()}) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String? description, int maxPeople, int slotInterval, List<IsibookIntervalPrice> intervalPrice, List images, List metaValue, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List tags, int minNumberSlotReserved, int maxNumberSlotReserved, List<int> spaces, int orderColumn, List<int> extras, bool canPayWithPoints, bool isDiscountActive, String? color, List imagesUrl, List<IsibookSpaceTimeSlot> timeSlots)?, {required TResult orElse()}) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsibookSpace to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String? description, int maxPeople, int slotInterval, List<IsibookIntervalPrice> intervalPrice, List images, List metaValue, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List tags, int minNumberSlotReserved, int maxNumberSlotReserved, List<int> spaces, int orderColumn, List<int> extras, bool canPayWithPoints, bool isDiscountActive, String? color, List imagesUrl, List<IsibookSpaceTimeSlot> timeSlots)) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int commercialId, String name, String? description, int maxPeople, int slotInterval, List<IsibookIntervalPrice> intervalPrice, List images, List metaValue, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List tags, int minNumberSlotReserved, int maxNumberSlotReserved, List<int> spaces, int orderColumn, List<int> extras, bool canPayWithPoints, bool isDiscountActive, String? color, List imagesUrl, List<IsibookSpaceTimeSlot> timeSlots)?) → TResult?

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited