IsibookSpacePatterns extension

Adds pattern-matching-related methods to IsibookSpace.

on

Methods

map<TResult extends Object?>(TResult $default(_IsibookSpace value)) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookSpace value)?) → TResult?

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookSpace value)?, {required TResult orElse()}) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String? description, int maxPeople, int slotInterval, List<IsibookIntervalPrice> intervalPrice, List images, List metaValue, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List tags, int minNumberSlotReserved, int maxNumberSlotReserved, List<int> spaces, int orderColumn, List<int> extras, bool canPayWithPoints, bool isDiscountActive, String? color, List imagesUrl, List<IsibookSpaceTimeSlot> timeSlots)?, {required TResult orElse()}) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int id, int commercialId, String name, String? description, int maxPeople, int slotInterval, List<IsibookIntervalPrice> intervalPrice, List images, List metaValue, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List tags, int minNumberSlotReserved, int maxNumberSlotReserved, List<int> spaces, int orderColumn, List<int> extras, bool canPayWithPoints, bool isDiscountActive, String? color, List imagesUrl, List<IsibookSpaceTimeSlot> timeSlots)) → TResult

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int commercialId, String name, String? description, int maxPeople, int slotInterval, List<IsibookIntervalPrice> intervalPrice, List images, List metaValue, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, List tags, int minNumberSlotReserved, int maxNumberSlotReserved, List<int> spaces, int orderColumn, List<int> extras, bool canPayWithPoints, bool isDiscountActive, String? color, List imagesUrl, List<IsibookSpaceTimeSlot> timeSlots)?) → TResult?

Available on IsibookSpace, provided by the IsibookSpacePatterns extension

A variant of when that fallback to returning null