IsibookSpaceTimeSlot class sealed

Available extensions
Annotations
  • @freezed

Constructors

IsibookSpaceTimeSlot({required int id, @JsonKey.new(name: 'isibook_space_id') required int isibookSpaceId, @JsonKey.new(name: 'day_of_week') required String dayOfWeek, @JsonKey.new(name: 'specific_date') String? specificDate, @JsonKey.new(name: 'start_time') required String startTime, @JsonKey.new(name: 'end_time') required String endTime, required bool available, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt})
const
factory
IsibookSpaceTimeSlot.fromJson(Map<String, dynamic> json)
factory

Properties

available bool
no setterinherited
copyWith → $IsibookSpaceTimeSlotCopyWith<IsibookSpaceTimeSlot>
Create a copy of IsibookSpaceTimeSlot with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → Jiffy
no setterinherited
dayOfWeek String
no setterinherited
endTime String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
isibookSpaceId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specificDate String?
no setterinherited
startTime String
no setterinherited
updatedAt → Jiffy
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IsibookSpaceTimeSlot value)) → TResult

Available on IsibookSpaceTimeSlot, provided by the IsibookSpaceTimeSlotPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IsibookSpaceTimeSlot value)?) → TResult?

Available on IsibookSpaceTimeSlot, provided by the IsibookSpaceTimeSlotPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IsibookSpaceTimeSlot value)?, {required TResult orElse()}) → TResult

Available on IsibookSpaceTimeSlot, provided by the IsibookSpaceTimeSlotPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, int isibookSpaceId, String dayOfWeek, String? specificDate, String startTime, String endTime, bool available, Jiffy createdAt, Jiffy updatedAt)?, {required TResult orElse()}) → TResult

Available on IsibookSpaceTimeSlot, provided by the IsibookSpaceTimeSlotPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IsibookSpaceTimeSlot to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, int isibookSpaceId, String dayOfWeek, String? specificDate, String startTime, String endTime, bool available, Jiffy createdAt, Jiffy updatedAt)) → TResult

Available on IsibookSpaceTimeSlot, provided by the IsibookSpaceTimeSlotPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, int isibookSpaceId, String dayOfWeek, String? specificDate, String startTime, String endTime, bool available, Jiffy createdAt, Jiffy updatedAt)?) → TResult?

Available on IsibookSpaceTimeSlot, provided by the IsibookSpaceTimeSlotPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited