IsibookReservation class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
IsibookReservation({required int id, @JsonKey.new(name: 'commercial_id') required int commercialId, @JsonKey.new(name: 'isibook_spaces_id') required int isibookSpacesId, @JsonKey.new(fromJson: _extrasFromJson, toJson: _extrasToJson) required List<
int> extras, @JsonKey.new(name: 'payment_type') required IsibookPaymentType paymentType, @JsonKey.new(name: 'electronic_confirmed') dynamic electronicConfirmed, @JsonKey.new(name: 'amount_payed') required num amountPayed, required int customers, @JsonKey.new(name: 'reservation_id') required int reservationId, @JsonKey.new(name: 'account_id') required int accountId, @JsonKey.new(name: 'account_temp') dynamic accountTemp, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt, @JsonKey.new(name: 'datetime_first_slot') @TimestampConverter() required Jiffy datetimeFirstSlot, @JsonKey.new(name: 'datetime_last_slot') @TimestampConverter() required Jiffy datetimeLastSlot, @JsonKey.new(name: 'cancel_at') @TimestampConverter() Jiffy? cancelAt, @JsonKey.new(name: 'cancel_by') String? cancelBy, @JsonKey.new(name: 'isibook_space_activity_id') int? isibookSpaceActivityId, @JsonKey.new(name: 'isibook_space_activity_connected_id') int? isibookSpaceActivityConnectedId, @JsonKey.new(name: 'recover_code_fattura') String? recoverCodeFattura, @JsonKey.new(name: 'error_fattura') String? errorFattura, @JsonKey.new(name: 'need_fattura') required bool needFattura, @JsonKey.new(name: 'backoffice') required bool backoffice, String? note}) -
constfactory
-
IsibookReservation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountId → int
-
no setterinherited
- accountTemp → dynamic
-
no setterinherited
- amountPayed → num
-
no setterinherited
- backoffice → bool
-
no setterinherited
- cancelAt → Jiffy?
-
no setterinherited
- cancelBy → String?
-
no setterinherited
- commercialId → int
-
no setterinherited
-
copyWith
→ $IsibookReservationCopyWith<
IsibookReservation> -
Create a copy of IsibookReservation
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → Jiffy
-
no setterinherited
- customers → int
-
no setterinherited
- datetimeFirstSlot → Jiffy
-
no setterinherited
- datetimeLastSlot → Jiffy
-
no setterinherited
- electronicConfirmed → dynamic
-
no setterinherited
- errorFattura → String?
-
no setterinherited
-
extras
→ List<
int> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- isibookSpaceActivityConnectedId → int?
-
no setterinherited
- isibookSpaceActivityId → int?
-
no setterinherited
- isibookSpacesId → int
-
no setterinherited
- needFattura → bool
-
no setterinherited
- note → String?
-
no setterinherited
- paymentType → IsibookPaymentType
-
no setterinherited
- recoverCodeFattura → String?
-
no setterinherited
- reservationId → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → Jiffy
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookReservation value)) → TResult -
Available on IsibookReservation, provided by the IsibookReservationPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookReservation value)?) → TResult? -
Available on IsibookReservation, provided by the IsibookReservationPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookReservation value)?, {required TResult orElse()}) → TResult -
Available on IsibookReservation, provided by the IsibookReservationPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int id, int commercialId, int isibookSpacesId, List< int> extras, IsibookPaymentType paymentType, dynamic electronicConfirmed, num amountPayed, int customers, int reservationId, int accountId, dynamic accountTemp, Jiffy createdAt, Jiffy updatedAt, Jiffy datetimeFirstSlot, Jiffy datetimeLastSlot, Jiffy? cancelAt, String? cancelBy, int? isibookSpaceActivityId, int? isibookSpaceActivityConnectedId, String? recoverCodeFattura, String? errorFattura, bool needFattura, bool backoffice, String? note)?, {required TResult orElse()}) → TResult -
Available on IsibookReservation, provided by the IsibookReservationPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookReservation to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int id, int commercialId, int isibookSpacesId, List< int> extras, IsibookPaymentType paymentType, dynamic electronicConfirmed, num amountPayed, int customers, int reservationId, int accountId, dynamic accountTemp, Jiffy createdAt, Jiffy updatedAt, Jiffy datetimeFirstSlot, Jiffy datetimeLastSlot, Jiffy? cancelAt, String? cancelBy, int? isibookSpaceActivityId, int? isibookSpaceActivityConnectedId, String? recoverCodeFattura, String? errorFattura, bool needFattura, bool backoffice, String? note)) → TResult -
Available on IsibookReservation, provided by the IsibookReservationPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int id, int commercialId, int isibookSpacesId, List< int> extras, IsibookPaymentType paymentType, dynamic electronicConfirmed, num amountPayed, int customers, int reservationId, int accountId, dynamic accountTemp, Jiffy createdAt, Jiffy updatedAt, Jiffy datetimeFirstSlot, Jiffy datetimeLastSlot, Jiffy? cancelAt, String? cancelBy, int? isibookSpaceActivityId, int? isibookSpaceActivityConnectedId, String? recoverCodeFattura, String? errorFattura, bool needFattura, bool backoffice, String? note)?) → TResult? -
Available on IsibookReservation, provided by the IsibookReservationPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited