IsibookReservationSlot class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- IsibookReservationSlot({required int id, @JsonKey.new(name: 'commercial_id') required int commercialId, @JsonKey.new(name: 'isibook_space_id') required int isibookSpaceId, @JsonKey.new(name: 'start_date') @TimestampConverter() required Jiffy startDate, required int duration, @JsonKey.new(name: 'payment_online') required bool paymentOnline, @JsonKey.new(name: 'payment_in_loco') required bool paymentInLoco, @JsonKey.new(name: 'note_slot') String? noteSlot, required String color, @JsonKey.new(name: 'deleted_at') @TimestampConverter() Jiffy? deletedAt, @JsonKey.new(name: 'created_at') @TimestampConverter() required Jiffy createdAt, @JsonKey.new(name: 'updated_at') @TimestampConverter() required Jiffy updatedAt, @JsonKey.new(name: 'isibook_space_reservation_id') int? isibookSpaceReservationId, @JsonKey.new(name: 'isibook_space_activity_id') int? isibookSpaceActivityId})
-
constfactory
-
IsibookReservationSlot.fromJson(Map<
String, dynamic> json) -
factory
Properties
- color → String
-
no setterinherited
- commercialId → int
-
no setterinherited
-
copyWith
→ $IsibookReservationSlotCopyWith<
IsibookReservationSlot> -
Create a copy of IsibookReservationSlot
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → Jiffy
-
no setterinherited
- deletedAt → Jiffy?
-
no setterinherited
- duration → int
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- isibookSpaceActivityId → int?
-
no setterinherited
- isibookSpaceId → int
-
no setterinherited
- isibookSpaceReservationId → int?
-
no setterinherited
- noteSlot → String?
-
no setterinherited
- paymentInLoco → bool
-
no setterinherited
- paymentOnline → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → Jiffy
-
no setterinherited
- updatedAt → Jiffy
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_IsibookReservationSlot value)) → TResult -
Available on IsibookReservationSlot, provided by the IsibookReservationSlotPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_IsibookReservationSlot value)?) → TResult? -
Available on IsibookReservationSlot, provided by the IsibookReservationSlotPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_IsibookReservationSlot value)?, {required TResult orElse()}) → TResult -
Available on IsibookReservationSlot, provided by the IsibookReservationSlotPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int id, int commercialId, int isibookSpaceId, Jiffy startDate, int duration, bool paymentOnline, bool paymentInLoco, String? noteSlot, String color, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, int? isibookSpaceReservationId, int? isibookSpaceActivityId)?, {required TResult orElse()}) → TResult -
Available on IsibookReservationSlot, provided by the IsibookReservationSlotPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this IsibookReservationSlot to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int id, int commercialId, int isibookSpaceId, Jiffy startDate, int duration, bool paymentOnline, bool paymentInLoco, String? noteSlot, String color, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, int? isibookSpaceReservationId, int? isibookSpaceActivityId)) → TResult -
Available on IsibookReservationSlot, provided by the IsibookReservationSlotPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int id, int commercialId, int isibookSpaceId, Jiffy startDate, int duration, bool paymentOnline, bool paymentInLoco, String? noteSlot, String color, Jiffy? deletedAt, Jiffy createdAt, Jiffy updatedAt, int? isibookSpaceReservationId, int? isibookSpaceActivityId)?) → TResult? -
Available on IsibookReservationSlot, provided by the IsibookReservationSlotPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited